package com.huiju.estateagents.center.taUser.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.center.taUser.entity.TaUser;
import com.huiju.estateagents.center.taUser.mapper.TaUserMapper;
import com.huiju.estateagents.center.taUser.service.ITaUserService;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.entity.TaOrg;
import com.huiju.estateagents.mapper.TaOrgMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 用户表  服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-09-11
 */
@Service
public class TaUserServiceImpl extends ServiceImpl<TaUserMapper, TaUser> implements ITaUserService {
	
	@Autowired
	private TaUserMapper taUserMapper;

	@Autowired
	private TaOrgMapper taOrgMapper;
	
	@Override
	public IPage<Map<String,Object>> getPageList(IPage pg) {
		List<Map<String,Object>> taUserList = taUserMapper.getPageList(pg);
		pg.setRecords(taUserList);
		return pg;
	}

	@Override
	public TaUser newUserAndOrg(TaUser taUser) throws Exception {
		if (StringUtils.isEmpty(taUser.getPhone())) {
			throw new Exception("电话号码不能为空");
		}
		if (StringUtils.isEmpty(taUser.getUserName())) {
			throw new Exception("用户名称不能为空");
		}

		if (StringUtils.isEmpty(taUser.getLoginName())) {
			taUser.setLoginName(taUser.getPhone());
		}

		QueryWrapper<TaUser> wrapper = new QueryWrapper<>();
		wrapper.eq("phone", taUser.getPhone()).or().eq("login_Name", taUser.getLoginName());
		List<TaUser> taUserList = this.list(wrapper);
		if (null != taUserList && taUserList.size() > 0) {
			throw new Exception("电话号码或登录名重复");
		}

		// 先插入 org
		TaOrg taOrg = new TaOrg();
		taOrg.setName(taUser.getOrgName());
		taOrg.setWaterMark(taUser.getWaterMark());
		taOrg.setCreateDate(LocalDateTime.now());
		if (taOrgMapper.insert(taOrg) < 1) {
			throw new Exception("生成用户公司信息失败");
		}

		taUser.setOrgId(taOrg.getOrgId());
		taUser.setIsAdmin(true);
		taUser.setStatus(CommConstant.STATUS_NORMAL);
		taUser.setCreateDate(LocalDateTime.now());
		if (!this.save(taUser)) {
			throw new Exception("生成用户信息失败");
		}

		return taUser;
	}

	@Override
	public TaUser getInfoWithOrg(Integer id) {
		TaUser taUser = this.getById(id);
		if (null == taUser) {
			return taUser;
		}

		TaOrg taOrg = taOrgMapper.selectById(taUser.getOrgId());
		if (null != taOrg) {
			taUser.setOrgName(taOrg.getName());
			taUser.setWaterMark(taOrg.getWaterMark());
		}

		taUser.setLoginPassword(null);
		return taUser;
	}

	@Override
	public void updateInfoWithOrg(TaUser taUser) throws Exception {
		TaOrg taOrg = taOrgMapper.selectById(taUser.getOrgId());
		if (null != taOrg) {
			taOrg.setName(taUser.getOrgName());
			taOrg.setWaterMark(taUser.getWaterMark());

			if (taOrgMapper.updateById(taOrg) < 1) {
				throw new Exception("更新用户公司信息失败");
			}
		}

		if (taUserMapper.updateById(taUser) < 1) {
			throw new Exception("更新用户信息失败");
		}
	}
}
